# Table of Contents

- [configure-workspace-meta-model-v4](<./configure-workspace-meta-model-v4.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Configure Workspace for Meta Model v4](<./Configure-Workspace-for-Meta-Model-v4.md>)
  - [Overview](<./Configure-Workspace-for-Meta-Model-v4/Overview.md>)
  - [Rename Three Existing Fact Sheet Types](<./Configure-Workspace-for-Meta-Model-v4/Rename-Three-Existing-Fact-Sheet-Types.md>)
  - [Introduce New Fact Sheet Type - Platform](<./Configure-Workspace-for-Meta-Model-v4/Introduce-New-Fact-Sheet-Type---Platform.md>)
  - [1. Create a New Fact Sheet Type](<./Configure-Workspace-for-Meta-Model-v4/1.-Create-a-New-Fact-Sheet-Type.md>)
  - [2. Add Sections - Strategic Support and Implementation](<./Configure-Workspace-for-Meta-Model-v4/2.-Add-Sections---Strategic-Support-and-Implementation.md>)
  - [3. Create Relations to Business Capability, Initiative, and Objective](<./Configure-Workspace-for-Meta-Model-v4/3.-Create-Relations-to-Business-Capability-Initiative-and-Objective.md>)
  - [4. Create Relations to Application and IT Component](<./Configure-Workspace-for-Meta-Model-v4/4.-Create-Relations-to-Application-and-IT-Component.md>)
  - [Add Fact Sheet Subtypes to Several Fact Sheet Types](<./Configure-Workspace-for-Meta-Model-v4/Add-Fact-Sheet-Subtypes-to-Several-Fact-Sheet-Types.md>)
  - [Fact Sheet Subtype Unique IDs and Translations](<./Configure-Workspace-for-Meta-Model-v4/Fact-Sheet-Subtype-Unique-IDs-and-Translations.md>)
  - [Introduce New Subsections and Fields to Business Capability](<./Configure-Workspace-for-Meta-Model-v4/Introduce-New-Subsections-and-Fields-to-Business-Capability.md>)
  - [1. Add the Subsection for Maturity in the Business Capability Fact Sheet](<./Configure-Workspace-for-Meta-Model-v4/1.-Add-the-Subsection-for-Maturity-in-the-Business-Capability-Fact-Sheet.md>)
  - [2. Add New Fact Sheet Fields in the Maturity Subsection](<./Configure-Workspace-for-Meta-Model-v4/2.-Add-New-Fact-Sheet-Fields-in-the-Maturity-Subsection.md>)
  - [Standardize Fact Sheet Colors and Order](<./Configure-Workspace-for-Meta-Model-v4/Standardize-Fact-Sheet-Colors-and-Order.md>)
  - [Was this page helpful?](<./Configure-Workspace-for-Meta-Model-v4/Was-this-page-helpful.md>)
